@@ -262,7 +262,24 @@ ESTIMATION <- function(data, model, group, itemtype = NULL, guess = 0, upper = 1
                          customGroup=customGroup[[1L]], spline_args=spline_args, monopoly.k=monopoly.k,
                          fulldata=opts$PrepList[[1L]]$fulldata, key=key, opts=opts,
                          gpcm_mats=gpcm_mats, internal_constraints=opts$internal_constraints,
-                         dcIRT_nphi=opts$dcIRT_nphi, dentype=opts$dentype, item.Q=opts$item.Q)
+                         dcIRT_nphi=opts$dcIRT_nphi, dentype=opts$dentype, item.Q=opts$item.Q,
+                         groupName=Data$groupNames[1])
+            if(length(unique(Data$model$x[,'OptionalGroups'])) > 1){
+                for(g in 2:Data$ngroups)
+                    PrepList[[g]] <-
+                        PrepData(data=Data$data, model=Data$model, itemtype=itemtype, guess=guess,
+                                 upper=upper, parprior=parprior, verbose=opts$verbose,
+                                 technical=opts$technical, parnumber=1L, BFACTOR=opts$dentype == 'bfactor',
+                                 grsm.block=Data$grsm.block, rsm.block=Data$rsm.block,
+                                 mixed.design=mixed.design, customItems=customItems,
+                                 customItemsData=customItemsData,
+                                 customGroup=customGroup[[1L]], spline_args=spline_args, monopoly.k=monopoly.k,
+                                 fulldata=opts$PrepList[[1L]]$fulldata, key=key, opts=opts,
+                                 gpcm_mats=gpcm_mats, internal_constraints=opts$internal_constraints,
+                                 dcIRT_nphi=opts$dcIRT_nphi, dentype=opts$dentype, item.Q=opts$item.Q,
+                                 groupName=Data$groupNames[g])
+
+            }
             if(!is.null(dots$Return_PrepList)) return(PrepListFull)
             if(!is.null(itemtypefull)){
                 for(g in 2L:nrow(itemtypefull)){
@@ -276,7 +293,8 @@ ESTIMATION <- function(data, model, group, itemtype = NULL, guess = 0, upper = 1
                                  customGroup=customGroup[[1L]], spline_args=spline_args, monopoly.k=monopoly.k,
                                  fulldata=opts$PrepList[[1L]]$fulldata, key=key, opts=opts,
                                  gpcm_mats=gpcm_mats, internal_constraints=opts$internal_constraints,
-                                 dcIRT_nphi=opts$dcIRT_nphi, dentype=opts$dentype, item.Q=opts$item.Q)
+                                 dcIRT_nphi=opts$dcIRT_nphi, dentype=opts$dentype, item.Q=opts$item.Q,
+                                 groupName=Data$groupNames[g])
                 }
             }
         }
@@ -291,7 +309,7 @@ ESTIMATION <- function(data, model, group, itemtype = NULL, guess = 0, upper = 1
             matrix(sapply(PrepListFull$pars, function(y) length(y@parnum)), nrow=1L)
         for(g in seq_len(Data$ngroups)){
             if(g != 1L){
-                if(is.null(itemtypefull))
+                if(is.null(itemtypefull) && length(unique(Data$model$x[,'OptionalGroups'])) == 1)
                     PrepList[[g]] <- list(pars=PrepList[[1L]]$pars)
                 else attr(PrepList[[g]]$pars, 'nclasspars') <-
                         sapply(PrepList[[g]]$pars, function(y) length(y@parnum))
@@ -563,13 +581,13 @@ ESTIMATION <- function(data, model, group, itemtype = NULL, guess = 0, upper = 1
         }
     }
     nmissingtabdata <- sum(is.na(rowSums(Data$tabdata)))
-    dfsubtr <- nestpars - nconstr
-    if(opts$dentype == 'EH') dfsubtr <- dfsubtr + (opts$quadpts - 1L) * Data$ngroups
-    else if(opts$dentype == 'EHW') dfsubtr <- dfsubtr + (opts$quadpts - 3L) * Data$ngroups
-    if(df <= dfsubtr)
+    nestpars <- nestpars - nconstr
+    if(opts$dentype == 'EH') nestpars <- nestpars + (opts$quadpts - 1L) * Data$ngroups
+    else if(opts$dentype == 'EHW') nestpars <- nestpars + (opts$quadpts - 3L) * Data$ngroups
+    if(df <= nestpars)
         stop('Too few degrees of freedom. There are only ', df, ' degrees of freedom but ',
-             dfsubtr, ' parameters were freely estimated.', call.=FALSE)
-    df <- df - dfsubtr
+             nestpars, ' parameters were freely estimated.', call.=FALSE)
+    df <- df - nestpars
     if(!is.null(customItems)){
         for(g in seq_len(Data$ngroups))
             PrepList[[g]]$exploratory <- FALSE
@@ -1034,7 +1052,7 @@ ESTIMATION <- function(data, model, group, itemtype = NULL, guess = 0, upper = 1
     }
     r <- rr
     N <- sum(r)
-    tmp <- dfsubtr
+    tmp <- nestpars
     AIC <- (-2) * logLik + 2 * tmp
     BIC <- (-2) * logLik + tmp*log(N)
     SABIC <- (-2) * logLik + tmp*log((N+2)/24)
@@ -1076,7 +1094,7 @@ ESTIMATION <- function(data, model, group, itemtype = NULL, guess = 0, upper = 1
     Model <- list(model=oldmodel, factorNames=PrepList[[1L]]$factorNames, itemtype=PrepList[[1L]]$itemtype,
                   itemloc=PrepList[[1L]]$itemloc, nfact=nfact, pis=pis,
                   Theta=Theta, constrain=constrain, nconstrain= opts$technical$nconstrain,
-                  parprior=parprior, nest=as.integer(dfsubtr),
+                  parprior=parprior, nest=as.integer(nestpars),
                   invariance=invariance, lrPars=lrPars, formulas=attr(mixed.design, 'formula'),
                   prodlist=PrepList[[1L]]$prodlist, nestpars=nestpars)
     if(!is.null(opts$technical$Etable)){
